==> cupertino_ffi-0.1.5.tar.gz: lib/src/core_foundation/mutable_array.dart <==
// Copyright (c) 2019 cupertino_ffi authors.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
// OR OTHER DEALINGS IN THE SOFTWARE.

import 'dart:ffi';

import 'package:cupertino_ffi/core_foundation.dart';

@unsized
class CFMutableArray extends Struct<CFMutableArray> {
  factory CFMutableArray._() {
    throw UnimplementedError();
  }

  static Pointer<CFMutableArray> allocate({int capacity = 16}) {
    return CFArrayCreateMutable(
      CFAllocator.getDefault(),
      capacity,
      Pointer.fromAddress(0),
    );
  }

  static Pointer<CFMutableArray> fromDart(List list) {
    if (list == null) {
      return Pointer<CFMutableArray>.fromAddress(0);
    }
    arcPush();
    try {
      final pointer = allocate(capacity: list.length);
      for (var item in list) {
        CFArrayAppendValue(pointer, CFType.fromDart(item));
      }
      return arcReturn(pointer);
    } finally {
      arcPop();
    }
  }
}

==> cupertino_ffi-0.1.6.tar.gz: lib/src/core_foundation/mutable_array.dart <==
// Copyright (c) 2019 cupertino_ffi authors.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
// OR OTHER DEALINGS IN THE SOFTWARE.

import 'dart:ffi';

import 'package:cupertino_ffi/core_foundation.dart';

@unsized
class CFMutableArray extends Struct {
  factory CFMutableArray._() {
    throw UnimplementedError();
  }

  static Pointer<CFMutableArray> allocate({int capacity = 16}) {
    return CFArrayCreateMutable(
      CFAllocator.getDefault(),
      capacity,
      Pointer.fromAddress(0),
    );
  }

  static Pointer<CFMutableArray> fromDart(List list) {
    if (list == null) {
      return Pointer<CFMutableArray>.fromAddress(0);
    }
    arcPush();
    try {
      final pointer = allocate(capacity: list.length);
      for (var item in list) {
        CFArrayAppendValue(pointer, CFType.fromDart(item));
      }
      return arcReturn(pointer);
    } finally {
      arcPop();
    }
  }
}
